@@ -3,9 +3,10 @@
 import json
 import os
 
+from v2ray_util import run_type
 from .config import Config
 from .utils import ColorStr, get_ip
-from .group import SS, Socks, Vmess, Vless, Mtproto, Quic, Group, Dyport, Trojan, Xtls
+from .group import SS, Socks, Vmess, Vless, Mtproto, Quic, Group, Dyport, Trojan
 
 class Stats:
     def __init__(self, status=False, door_port=0):
@@ -72,12 +73,12 @@ class Profile:
                 self.group_list.append(group)
         
         if len(self.group_list) == 0:
-            print("v2ray json no streamSettings item, please run {} to recreate v2ray json!".format(ColorStr.cyan("v2ray_util new")))
+            print("{} json no streamSettings item, please run {} to recreate {} json!".format(run_type, ColorStr.cyan("{} new".format(run_type)), run_type))
 
         del self.config
 
     def parse_group(self, part_json, group_index, local_ip):
-        dyp, quic, end_port, tfo, header, tls, path, host, conf_ip = Dyport(), None, None, None, "", "", "", "", local_ip
+        dyp, quic, end_port, tfo, header, tls, path, host, conf_ip, serviceName, mode = Dyport(), None, None, None, "", "", "", "", local_ip, "", "gun"
         
         protocol = part_json["protocol"]
 
@@ -122,10 +123,16 @@ class Profile:
 
             if conf_stream["network"] == "kcp" and "header" in conf_stream["kcpSettings"]:
                 header = conf_stream["kcpSettings"]["header"]["type"]
+                if "seed" in conf_stream["kcpSettings"]:
+                    path = conf_stream["kcpSettings"]["seed"]
             
             if conf_stream["network"] == "quic" and conf_stream["quicSettings"]:
                 quic_settings = conf_stream["quicSettings"]
                 quic = Quic(quic_settings["security"], quic_settings["key"], quic_settings["header"]["type"])
+            if conf_stream["network"] == "grpc" and conf_stream["grpcSettings"]:
+                serviceName = conf_stream["grpcSettings"]["serviceName"]
+                if "multiMode" in conf_stream["grpcSettings"] and conf_stream["grpcSettings"]["multiMode"]:
+                    mode = "multi"
         
         group = Group(conf_ip, port,  end_port=end_port, tls=tls, tfo=tfo, dyp=dyp, index=group_index)
 
@@ -144,7 +151,7 @@ class Profile:
             clients=conf_settings["users"]
 
         for client in clients:
-            email, node = "", None
+            email, node, flow = "", None, ""
             self.user_number = self.user_number + 1
             if "email" in client and client["email"]:
                 email = client["email"]
@@ -160,9 +167,8 @@ class Profile:
 
             elif protocol == "vless":
                 if tls == "xtls":
-                    node = Xtls(client["id"], self.user_number, conf_settings["decryption"], email, client["flow"])
-                else:
-                    node = Vless(client["id"], self.user_number, conf_settings["decryption"], email, conf_stream["network"], path, host)
+                    flow = client["flow"]
+                node = Vless(client["id"], self.user_number, conf_settings["decryption"], email, conf_stream["network"], path, host, header, flow, serviceName, mode)
 
             elif protocol == "trojan":
                 node = Trojan(self.user_number, client["password"], email)
